"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.isEIP712Transaction = isEIP712Transaction;
exports.assertEip712Request = assertEip712Request;
const utils_1 = require("viem/utils");
const eip712_js_1 = require("./errors/eip712.js");
function isEIP712Transaction(transaction) {
    if (transaction.type === 'eip712')
        return true;
    if (('customSignature' in transaction && transaction.customSignature) ||
        ('paymaster' in transaction && transaction.paymaster) ||
        ('paymasterInput' in transaction && transaction.paymasterInput) ||
        ('gasPerPubdata' in transaction &&
            typeof transaction.gasPerPubdata === 'bigint') ||
        ('factoryDeps' in transaction && transaction.factoryDeps))
        return true;
    return false;
}
function assertEip712Request(args) {
    if (!isEIP712Transaction(args))
        throw new eip712_js_1.InvalidEip712TransactionError();
    (0, utils_1.assertRequest)(args);
}
//# sourceMappingURL=eip712.js.map